# pynetcf #

Basic python classes that map to netCDF files on disk written according
to the [Climate and Forecast metadata conventions](http://cfconventions.org/Data/cf-conventions/cf-conventions-1.6/build/cf-conventions.html)

This is a first draft which has a lot of room for improvements, this is especially true for the time series based representations.

## Documentation

[![Documentation Status](https://readthedocs.org/projects/pynetcf/badge/?version=latest)](http://pynetcf.readthedocs.org/en/latest/?badge=latest)

## How to use

For now please see the tests for examples on how to use the classes.
